You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@royale.apache.org by ah...@apache.org on 2021/12/29 02:52:43 UTC

[royale-compiler] branch develop updated: maven build needs more goog files too

This is an automated email from the ASF dual-hosted git repository.

aharui pushed a commit to branch develop
in repository https://gitbox.apache.org/repos/asf/royale-compiler.git


The following commit(s) were added to refs/heads/develop by this push:
     new faa733b  maven build needs more goog files too
faa733b is described below

commit faa733b37615ea62c0d16fcf14f2a536b88b89a1
Author: Alex Harui <ah...@apache.org>
AuthorDate: Tue Dec 28 18:52:38 2021 -0800

    maven build needs more goog files too
---
 .../codegen/mxml/royale/MXMLRoyalePublisher.java   |   4 +-
 .../resources/royale/closure-whitelist.properites  |  44 ---
 .../resources/royale/closure-whitelist.properties  | 299 +++++++++++++++++++++
 3 files changed, 301 insertions(+), 46 deletions(-)

diff --git a/compiler-jx/src/main/resources/royale/closure-whitelist.properites b/compiler-jx/src/main/resources/royale/closure-whitelist.properites
deleted file mode 100644
index 5fd746b..0000000
--- a/compiler-jx/src/main/resources/royale/closure-whitelist.properites
+++ /dev/null
@@ -1,44 +0,0 @@
-
-# Licensed to the Apache Software Foundation (ASF) under one or more
-# contributor license agreements.  See the NOTICE file distributed with
-# this work for additional information regarding copyright ownership.
-# The ASF licenses this file to You under the Apache License, Version 2.0
-# (the "License"); you may not use this file except in compliance with
-# the License.  You may obtain a copy of the License at
-#
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-goog/array/array.js
-goog/asserts/asserts.js
-goog/base.js
-goog/deps.js
-goog/debug/entrypointregistry.js
-goog/debug/error.js
-goog/disposable/disposable.js
-goog/disposable/idisposable.js
-goog/dom/nodetype.js
-goog/events/browserevent.js
-goog/events/browserfeature.js
-goog/events/event.js
-goog/events/eventid.js
-goog/events/events.js
-goog/events/eventtarget.js
-goog/events/eventtype.js
-goog/events/listenable.js
-goog/events/listener.js
-goog/events/listenermap.js
-goog/labs/useragent/browser.js
-goog/labs/useragent/engine.js
-goog/labs/useragent/platform.js
-goog/labs/useragent/util.js
-goog/object/object.js
-goog/reflect/reflect.js
-goog/string/string.js
-goog/useragent/useragent.js
-goog/bootstrap/nodejs.js
\ No newline at end of file
diff --git a/compiler-jx/src/main/resources/royale/closure-whitelist.properties b/compiler-jx/src/main/resources/royale/closure-whitelist.properties
new file mode 100644
index 0000000..125b7eb
--- /dev/null
+++ b/compiler-jx/src/main/resources/royale/closure-whitelist.properties
@@ -0,0 +1,299 @@
+
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+goog/array/array.js
+goog/asserts/asserts.js
+goog/base.js
+goog/deps.js
+goog/debug/console_test.js
+goog/debug/divconsole.js
+goog/debug/entrypointregistry_test.js
+goog/debug/logger.js
+goog/debug/errorcontext.js
+goog/debug/fpsdisplay.js
+goog/debug/logrecordserializer_test.js
+goog/debug/tracer_test.js
+goog/debug/relativetimeprovider.js
+goog/debug/logbuffer.js
+goog/debug/debugwindow_test.js
+goog/debug/formatter.js
+goog/debug/fancywindow.js
+goog/debug/console.js
+goog/debug/errorhandler_async_test.js
+goog/debug/logrecord.js
+goog/debug/debugwindow.js
+goog/debug/logrecordserializer.js
+goog/debug/error.js
+goog/debug/errorhandler.js
+goog/debug/entrypointregistry.js
+goog/debug/debug_test.js
+goog/debug/devcss/devcss.js
+goog/debug/devcss/devcss_test.js
+goog/debug/devcss/devcssrunner.js
+goog/debug/logger_test.js
+goog/debug/error_test.js
+goog/debug/errorhandlerweakdep.js
+goog/debug/tracer.js
+goog/debug/errorcontext_test.js
+goog/debug/formatter_test.js
+goog/debug/logbuffer_test.js
+goog/debug/enhanceerror_test.js
+goog/debug/errorreporter_test.js
+goog/debug/fpsdisplay_test.js
+goog/debug/errorhandler_test.js
+goog/debug/debug.js
+goog/debug/errorreporter.js
+goog/disposable/idisposable.js
+goog/disposable/disposable.js
+goog/dom/tags_test.js
+goog/dom/controlrange_test.js
+goog/dom/range.js
+goog/dom/asserts_test.js
+goog/dom/textrange_test.js
+goog/dom/annotate.js
+goog/dom/safe_test.js
+goog/dom/savedcaretrange.js
+goog/dom/iframe.js
+goog/dom/fontsizemonitor.js
+goog/dom/abstractrange_test.js
+goog/dom/xml.js
+goog/dom/iframe_test.js
+goog/dom/multirange_test.js
+goog/dom/annotate_test.js
+goog/dom/tags.js
+goog/dom/viewportsizemonitor_test.js
+goog/dom/iter.js
+goog/dom/tagname.js
+goog/dom/tagname_test.js
+goog/dom/vendor_test.js
+goog/dom/iter_test.js
+goog/dom/textrangeiterator_test.js
+goog/dom/inputtype_test.js
+goog/dom/range_test.js
+goog/dom/safe.js
+goog/dom/htmlelement.js
+goog/dom/classlist_test.js
+goog/dom/uri_test.js
+goog/dom/vendor.js
+goog/dom/asserts.js
+goog/dom/dom_compile_test.js
+goog/dom/savedrange.js
+goog/dom/bufferedviewportsizemonitor_test.js
+goog/dom/dom_test.js
+goog/dom/classes.js
+goog/dom/savedcaretrange_test.js
+goog/dom/nodeoffset_test.js
+goog/dom/selection.js
+goog/dom/bufferedviewportsizemonitor.js
+goog/dom/rangeendpoint.js
+goog/dom/tagiterator.js
+goog/dom/nodeiterator_test.js
+goog/dom/xml_test.js
+goog/dom/dom.js
+goog/dom/attr.js
+goog/dom/tagiterator_test.js
+goog/dom/forms_test.js
+goog/dom/textassert_test.js
+goog/dom/nodetype.js
+goog/dom/abstractmultirange.js
+goog/dom/browserfeature.js
+goog/dom/fontsizemonitor_test.js
+goog/dom/savedrange_test.js
+goog/dom/textrange.js
+goog/dom/browserrange/ierange.js
+goog/dom/browserrange/browserrange_test.js
+goog/dom/browserrange/w3crange.js
+goog/dom/browserrange/webkitrange.js
+goog/dom/browserrange/geckorange.js
+goog/dom/browserrange/browserrange.js
+goog/dom/browserrange/abstractrange.js
+goog/dom/browserrange/operarange.js
+goog/dom/textrangeiterator.js
+goog/dom/classlist.js
+goog/dom/pattern/pattern_test.js
+goog/dom/pattern/sequence.js
+goog/dom/pattern/allchildren.js
+goog/dom/pattern/starttag.js
+goog/dom/pattern/pattern.js
+goog/dom/pattern/endtag.js
+goog/dom/pattern/childmatches.js
+goog/dom/pattern/matcher.js
+goog/dom/pattern/matcher_test.js
+goog/dom/pattern/tag.js
+goog/dom/pattern/nodetype.js
+goog/dom/pattern/repeat.js
+goog/dom/pattern/callback/test.js
+goog/dom/pattern/callback/callback.js
+goog/dom/pattern/callback/counter.js
+goog/dom/pattern/abstractpattern.js
+goog/dom/pattern/fulltag.js
+goog/dom/pattern/text.js
+goog/dom/forms.js
+goog/dom/abstractrange.js
+goog/dom/dataset_test.js
+goog/dom/dataset.js
+goog/dom/classes_test.js
+goog/dom/viewportsizemonitor.js
+goog/dom/animationframe/animationframe.js
+goog/dom/animationframe/animationframe_test.js
+goog/dom/animationframe/polyfill.js
+goog/dom/selection_test.js
+goog/dom/nodeoffset.js
+goog/dom/controlrange.js
+goog/dom/multirange.js
+goog/dom/textassert.js
+goog/dom/fullscreen.js
+goog/dom/nodeiterator.js
+goog/dom/inputtype.js
+goog/dom/fullscreen_test.js
+goog/dom/uri.js
+goog/events/eventtarget.js
+goog/events/events.js
+goog/events/listenable.js
+goog/events/event.js
+goog/events/listenermap.js
+goog/events/listener.js
+goog/events/browserfeature.js
+goog/events/browserevent.js
+goog/events/eventid.js
+goog/events/eventtype.js
+goog/labs/useragent/util.js
+goog/labs/useragent/engine.js
+goog/labs/useragent/platform.js
+goog/labs/useragent/browser.js
+goog/object/object.js
+goog/useragent/jscript.js
+goog/useragent/iphoto.js
+goog/useragent/platform_test.js
+goog/useragent/useragent_quirks_test.js
+goog/useragent/product_isversion.js
+goog/useragent/useragenttestutil.js
+goog/useragent/useragent.js
+goog/useragent/product_test.js
+goog/useragent/adobereader.js
+goog/useragent/keyboard.js
+goog/useragent/jscript_test.js
+goog/useragent/flash_test.js
+goog/useragent/useragent_test.js
+goog/useragent/platform.js
+goog/useragent/adobereader_test.js
+goog/useragent/keyboard_test.js
+goog/useragent/product.js
+goog/useragent/flash.js
+goog/bootstrap/nodejs.js
+goog/reflect/reflect.js
+goog/html/textextractor.js
+goog/html/silverlight.js
+goog/html/safehtmlformatter.js
+goog/html/trustedresourceurl.js
+goog/html/safehtmlformatter_test.js
+goog/html/safescript_test.js
+goog/html/cssspecificity.js
+goog/html/uncheckedconversions_test.js
+goog/html/sanitizer/safedomtreeprocessor.js
+goog/html/sanitizer/tagblacklist.js
+goog/html/sanitizer/elementweakmap.js
+goog/html/sanitizer/htmlsanitizer.js
+goog/html/sanitizer/htmlsanitizer_test.js
+goog/html/sanitizer/attributewhitelist.js
+goog/html/sanitizer/unsafe_test.js
+goog/html/sanitizer/csssanitizer.js
+goog/html/sanitizer/tagwhitelist.js
+goog/html/sanitizer/noclobber_test.js
+goog/html/sanitizer/unsafe.js
+goog/html/sanitizer/noclobber.js
+goog/html/sanitizer/safedomtreeprocessor_test.js
+goog/html/sanitizer/csssanitizer_test.js
+goog/html/sanitizer/elementweakmap_test.js
+goog/html/safeurl_test_vectors.js
+goog/html/safeurl.js
+goog/html/utils_test.js
+goog/html/safeurl_test.js
+goog/html/testing.js
+goog/html/safestyle.js
+goog/html/legacyconversions_test.js
+goog/html/legacyconversions.js
+goog/html/cssspecificity_test.js
+goog/html/uncheckedconversions.js
+goog/html/textextractor_test.js
+goog/html/safestylesheet.js
+goog/html/safestyle_test.js
+goog/html/utils.js
+goog/html/safehtml.js
+goog/html/flash_test.js
+goog/html/flash.js
+goog/html/trustedresourceurl_test.js
+goog/html/safestylesheet_test.js
+goog/html/safehtml_test.js
+goog/html/safescript.js
+goog/html/silverlight_test.js
+goog/math/bezier.js
+goog/math/line.js
+goog/math/range.js
+goog/math/affinetransform_test.js
+goog/math/rect.js
+goog/math/size.js
+goog/math/coordinate.js
+goog/math/interpolator/pchip1_test.js
+goog/math/interpolator/interpolator1.js
+goog/math/interpolator/linear1.js
+goog/math/interpolator/spline1.js
+goog/math/interpolator/spline1_test.js
+goog/math/interpolator/linear1_test.js
+goog/math/interpolator/pchip1.js
+goog/math/exponentialbackoff.js
+goog/math/exponentialbackoff_test.js
+goog/math/rect_test.js
+goog/math/box.js
+goog/math/matrix.js
+goog/math/path_test.js
+goog/math/size_test.js
+goog/math/tdma_test.js
+goog/math/tdma.js
+goog/math/paths.js
+goog/math/range_test.js
+goog/math/matrix_test.js
+goog/math/integer_test.js
+goog/math/affinetransform.js
+goog/math/bezier_test.js
+goog/math/irect.js
+goog/math/vec3.js
+goog/math/long.js
+goog/math/long_test.js
+goog/math/rangeset_test.js
+goog/math/rangeset.js
+goog/math/math.js
+goog/math/paths_test.js
+goog/math/path.js
+goog/math/math_test.js
+goog/math/vec2.js
+goog/math/box_test.js
+goog/math/vec3_test.js
+goog/math/coordinate3.js
+goog/math/coordinate_test.js
+goog/math/integer.js
+goog/math/line_test.js
+goog/math/coordinate3_test.js
+goog/math/vec2_test.js
+goog/functions/functions.js
+goog/functions/functions_test.js
+goog/log/log_test.js
+goog/log/log.js
+goog/string/typedstring.js
+goog/string/string.js
+goog/string/const.js
+goog/i18n/bidi.js
+goog/fs/url.js
diff --git a/compiler-jx/src/main/java/org/apache/royale/compiler/internal/codegen/mxml/royale/MXMLRoyalePublisher.java b/compiler-jx/src/main/java/org/apache/royale/compiler/internal/codegen/mxml/royale/MXMLRoyalePublisher.java
index 14d251d..ec52ced 100644
--- a/compiler-jx/src/main/java/org/apache/royale/compiler/internal/codegen/mxml/royale/MXMLRoyalePublisher.java
+++ b/compiler-jx/src/main/java/org/apache/royale/compiler/internal/codegen/mxml/royale/MXMLRoyalePublisher.java
@@ -354,10 +354,10 @@ public class MXMLRoyalePublisher extends JSGoogPublisher implements IJSGoogPubli
             if (closureLibraryJar != null)
             {
                 // We don't want to add all files to the classpath, so we only output the
                 // resources contained in 'closure-whitelist.properites' to the output.
                 Properties whiteList = new Properties();
                 whiteList.load(Thread.currentThread().getContextClassLoader().getResourceAsStream(
-                        "royale/closure-whitelist.properites"));
+                        "royale/closure-whitelist.properties"));
 
                 // Add the closure files from classpath.
                 closureSourceFiles = getClasspathResources(closureLibraryJar, whiteList);
@@ -354,10 +354,10 @@ public class MXMLRoyalePublisher extends JSGoogPublisher implements IJSGoogPubli
             {
                 // We don't want to add all files to the classpath, so we only output the
-                // resources contained in 'closure-whitelist.properites' to the output.
+                // resources contained in 'closure-whitelist.properties' to the output.
                 Properties whiteList = new Properties();
                 whiteList.load(Thread.currentThread().getContextClassLoader().getResourceAsStream(